﻿using System.Numerics;
using System.Collections.Generic;

namespace Model.Cartography
{
    public interface IMapObjectBlueprint
    {
        /// <summary>
        /// Returns the 2D dimensions of the object.
        /// </summary>
        /// <returns></returns>
        Vec2i GetSize();

        /// <summary>
        /// Returns a list of navigable cells in the object.
        /// </summary>
        /// <returns></returns>
        IEnumerable<NavigableCell> GetNavigableCells();

        /// <summary>
        /// Called by Map when it wants to determine whether an object can be placed.
        /// <paramref>mapPosition</paramref> is guaranteed to be correct and valid
        /// given that the dimensions haven't changed since the last call to <c>GetSize</c>.
        /// </summary>
        /// <param name="map"></param>
        /// <param name="mapPosition"></param>
        /// <returns>true if the object can be built, false otherwise</returns>
        bool CanPlace(Map map, MapPosition mapPosition);

        /// <summary>
        /// Called by Map when it wants to build the given object.
        /// </summary>
        /// <param name="map"></param>
        /// <param name="position"></param>
        /// <returns>the created object</returns>
        MapObject Place(Map map, MapObjectPosition position);
    }
}
