using System.Collections.Generic;
using System.Numerics;

using Model.Cartography.Nav;
using Model.Common;
using Model.People;

namespace Model.Cartography
{
    /// <summary>
    /// ABC of all objects that can be on the map.
    /// </summary>
    public abstract class MapObject : WorldEntity
    {
        /// <summary>
        /// List of vertices in all <see cref="Cell">Cells</see> of the object.
        /// </summary>
        public ICollection<VertexHandle> Vertices = new List<VertexHandle>();
        protected MapObjectPosition position;

        protected MapObject(MapObjectPosition position) : base(position) {
            this.position = position;
        }

        public enum EnterResult {
            /// <summary>
            /// Interaction successful.
            /// </summary>
            SUCCESS,

            /// <summary>
            /// Try again.
            /// </summary>
            AGAIN,

            /// <summary>
            /// Interaction cannot be started.
            /// </summary>
            FAIL,
        }

        /// <summary>
        /// Called by a <see cref="Person" /> when it wants to interact with the entity.
        /// </summary>
        /// <param name="p"></param>
        /// <param name="pos"></param>
        /// <returns></returns>
        public virtual EnterResult Enter(Person p, ref Vector2 pos) => EnterResult.FAIL;

        /// <summary>
        /// Called by a <see cref="Person" /> when it wants to stop the interaction with the entity.
        /// </summary>
        /// <param name="p"></param>
        public virtual void Exit(Person p) { }
    }
}
