using System;

namespace Model.Cartography.Nav
{
    /// <summary>
    /// Represents a path between two vertices in a <see ref="NavigationGraph"/>.
    /// </summary>
    public struct RouteHandle
    {
        private NavigationGraph navgraph;
        private VertexHandle at, to, next;

        /// <summary>
        /// Query whether the current node is valid and at the destination.
        /// </summary>
        public bool Arrived { get => at.Valid && at == to; }

        /// <summary>
        /// Construct a new RouteHandle instance.
        /// </summary>
        /// <param name="navgraph">the <c>NavigationGraph</c> the vertices are in</param>
        /// <param name="at">beginning of the path</param>
        /// <param name="to">end of the path</param>
        public RouteHandle(NavigationGraph navgraph, VertexHandle at, VertexHandle to) {
            this.navgraph = navgraph;
            this.at = at;
            this.to = to;
            this.next = VertexHandle.INVALID;
        }

        /// <summary>
        /// Returns the next vertex on the path.
        /// </summary>
        /// <returns>the handle of the next vertex on the path</returns>
        public VertexHandle GetNext() {
            return next = navgraph.GetNextOnRoute(at, to);
        }

        /// <summary>
        /// Changes the current node to the one returned by the latest <c>GetNext</c> call.
        /// </summary>
        /// <returns>the handle of the next, now current vertex on the path</returns>
        public VertexHandle CommitStep() {
            if (!next.Valid)
                throw new InvalidOperationException();

            return at = next;
        }
    }
}
