namespace Model.Cartography.Nav
{
    public struct VertexHandle
    {
        public static readonly VertexHandle INVALID = new VertexHandle(NavigationGraph.INVALID);

        /// <summary>
        /// The numeric identifier of the vertex.
        /// </summary>
        public int ID { get; }

        /// <summary>
        /// Whether or not the vertex is valid.
        /// </summary>
        public bool Valid { get => this != INVALID; }

        /// <summary>
        /// Constructs a <see cref="VertexHandle" /> with a given identifier.
        /// </summary>
        /// <param name="ID"></param>
        public VertexHandle(int ID) {
            this.ID = ID;
        }

        public static implicit operator int(VertexHandle v) => v.ID;
        public static explicit operator VertexHandle(int ID) => new VertexHandle(ID);
        public static bool operator == (VertexHandle a, VertexHandle b) => a.ID == b.ID;
        public static bool operator != (VertexHandle a, VertexHandle b) => a.ID != b.ID;

        public override bool Equals(object obj) => (obj is VertexHandle v) && (v == this);

        public override int GetHashCode() => ID.GetHashCode();

        public override string ToString() {
            return $"Vertex {{ ID = {ID} }}";
        }
    }
}
