using System;

namespace Model.Cartography
{
    /// <summary>
    /// Represents one of the four canonical directions.
    /// </summary>
    [Serializable]
    public enum Orientation
    {
        NORTH,
        WEST,
        SOUTH,
        EAST,
        COUNT
    }

    public static class OrientationExtensions {
        /// <summary>
        /// Rotates a given direction by a given amount.
        /// </summary>
        /// <param name="direction">direction to rotate</param>
        /// <param name="by">the amount of rotation</param>
        /// <returns>the rotated orientation</returns>
        public static Orientation rotate(this Orientation direction, Orientation by)
            => (Orientation) (((int) direction + (int) by) % (int) Orientation.COUNT);
    }
}
