using System;
using System.Numerics;

namespace Model.Cartography
{
    [Serializable]
    public struct Vec2i
    {
        public int X, Y;

        public Vec2i(int x, int y) {
            X = x;
            Y = y;
        }

        /// <summary>
        /// Rotates the vector by 90 degress counter-clockwise.
        /// </summary>
        public void Rotate90CCW() => (X, Y) = (-Y, X);

        /// <summary>
        /// Rotates the vector by 90 degress clockwise.
        /// </summary>
        public void Rotate90CW() => (X, Y) = (Y, -X);

        /// <summary>
        /// Rotates the vector by 180 degrees.
        /// </summary>
        public void Rotate180() => (X, Y) = (-X, -Y);

        /// <summary>
        /// Swaps the coordinates of the vector.
        /// </summary>
        public void Swap() => (X, Y) = (Y, X);

        /// <summary>
        /// Adds the given quantities to the coordinates of the vector.
        /// </summary>
        /// <param name="dx"></param>
        /// <param name="dy"></param>
        /// <returns></returns>
        public Vec2i Add(int dx, int dy) {
            X += dx;
            Y += dy;

            return this;
        }

        /// <summary>
        /// Adds another vector to this one.
        /// </summary>
        /// <param name="delta"></param>
        /// <returns></returns>
        public Vec2i Add(in Vec2i delta) => Add(delta.X, delta.Y);

        public static implicit operator Vector2(Vec2i v) => new Vector2(v.X, v.Y);
        public static bool operator == (in Vec2i a, in Vec2i b) => a.X == b.X && a.Y == b.Y;
        public static bool operator != (in Vec2i a, in Vec2i b) => !(a == b);

        public override bool Equals(object obj) => (obj is Vec2i v) && (v == this);

        public override int GetHashCode() => X.GetHashCode() + Y.GetHashCode();
    }
}
