using Model.Cartography;
using Model.Inspection;

namespace Model.Common
{
    /// <summary>
    /// Interface for a class that can build <see cref="MapObject"/>s.
    /// </summary>
    public interface IBuilder
    {
        /// <summary>
        /// Decides if a <see cref="MapObject"/> can be built.
        /// </summary>
        /// <param name="blueprint">bulueprint of the object</param>
        /// <param name="mapPosition">position of the object</param>
        /// <returns><c>true</c> if the buliding is possible, <c>false</c> otherwise</returns>
        bool CanBuild(IMapObjectBlueprint blueprint, MapPosition mapPosition);

        /// <summary>
        /// Builds the <see cref="MapObject"/>.
        /// </summary>
        /// <param name="blueprint">bulueprint of the object</param>
        /// <param name="mapPosition">position of the object</param>
        /// <returns>the <see cref="MapObject"/> built under two different interfaces</returns>
        (IDisplayable, IInspectable) Build(IMapObjectBlueprint blueprint, MapPosition mapPosition);
    }
}
