using System;

namespace Model.Common
{
    /// <summary>
    /// <see cref="ModelObjectHandle"/> provides an event that is invoked when an object (in the model) is deleted.
    /// Having a handle is a requirement for any class implementing the <see cref="IDisplayable"/> interface.
    /// </summary>
    public class ModelObjectHandle
    {
        public event EventHandler OnDeleted;

        /// <summary>
        /// Invokes the <see cref="OnDeleted"/> event.
        /// </summary>
        /// <param name="args">unused</param>
        internal void Delete(EventArgs args) {
            OnDeleted?.Invoke(this, args);
        }
    }
}
