using System.Collections.Generic;
using System.Numerics;

using Model.Inspection;

namespace Model.Common
{
    /// <summary>
    /// Base class of all the entities (buildings, pavements, people).
    /// </summary>
    public class WorldEntity : IDisplayable, IInspectable
    {
        private Vector2 position;
        private bool visible;
        private ModelObjectHandle handle;

        public Vector2 Position { get => position; set => position = value; }
        public bool Visible { get => visible; set => visible = value; }

        public ModelObjectHandle Handle => handle;

        public virtual string Name => $"{GetType().Name}@{GetHashCode()}";
        protected readonly Property<string> UniqueName;

        /// <summary>
        /// Constructor of <see cref="WorldEntity"/>.
        /// </summary>
        /// <param name="position">the position of the entity</param>
        protected WorldEntity(Vector2 position) {
            this.UniqueName = new Property<string>("ID", $"{GetType().Name}@{GetHashCode()}");
            this.position = position;
            handle = new ModelObjectHandle();
        }

        /// <summary>
        /// Returns every <see cref="Property{T}"/> available.
        /// </summary>
        /// <returns>a list of all the properties</returns>
        public virtual IEnumerable<InspectionElement> GetProperties() => Inspector.GetProperties(this);

        /// <summary>
        /// No commands available.
        /// </summary>
        /// <returns><c>null</c></returns>
        public virtual IEnumerable<Command> GetCommands() => null;
    }
}
