using System;
using System.Reflection;
using System.Collections.Generic;

namespace Model.Inspection
{
    public static class Inspector
    {
        private static readonly Type PropertyType = typeof(Property<>);

        /// <summary>
        /// Returns a list of <see cref="Property">properties</see> of an arbitrary object.
        /// </summary>
        /// <param name="o">the object</param>
        /// <returns></returns>
        public static IEnumerable<InspectionElement> GetProperties(object o) {
            var T = o.GetType();

            List<InspectionElement> props = new List<InspectionElement>();

            foreach (var f in T.GetFields(BindingFlags.Instance | BindingFlags.Public | BindingFlags.NonPublic)) {
                if (!f.FieldType.IsGenericType)
                    continue;

                if (f.FieldType.GetGenericTypeDefinition() != PropertyType)
                    continue;

                InspectionElement prop = (InspectionElement) f.GetValue(o);

                if (prop == null)
                    continue;

                props.Add(prop);
            }

            return props;
        }
    }
}
