using System;

using Model.Cartography;

namespace Model.Landscape.Blueprints
{
    /// <summary>
    /// Blueprint for a <see cref="Building{T}"/>.
    /// </summary>
    [Serializable]
    public abstract class BuildingBlueprint : ObjectBlueprint
    {
        public int MaintenanceCost;
        public int MaintenanceInterval = 10;
        public int ConstructionTime;
        public int RepairTime;
        public int RepairCost;
        /// <summary>
        /// Expected time before the building needs maintenance.<br/>
        /// If set to 0, the building will never break.
        /// </summary>
        public int ExpectedLifeSpan;

        /// <summary>
        /// Decides if a building can be placed.<br/>
        /// It cannot be if it would be bordering a <see cref="QueuePavement"/> as that would make
        /// the destination of the queue ambiguous.
        /// </summary>
        /// <param name="map">same as <see cref="Common.Simulation.Map"/></param>
        /// <param name="mapPosition">position of the building</param>
        /// <returns><c>true</c> if the building can be placed, <c>false</c> otherwise</returns>
        public override bool CanPlace(Map map, MapPosition mapPosition) {
            var navcells = GetNavigableCells();

            if (navcells == null)
                return true;

            foreach (var nc in navcells) {
                var p = Map.InnerToWorldPosition(this, mapPosition, nc.Position);

                foreach (var n in map.GetNeighbors(p)) {
                    if (map.GetObjectAt(n) is QueuePavement)
                        return false;
                }
            }

            return true;
        }
    }
}
