using System;
using System.Collections.Generic;

using Model.Cartography;

namespace Model.Landscape.Blueprints
{
    /// <summary>
    /// Blueprint for a <see cref="MapObject"/>.
    /// </summary>
    [Serializable]
    public abstract class ObjectBlueprint : IMapObjectBlueprint
    {
        public string Name;
        public Vec2i Size;
        public int ConstructionCost;
        public List<NavigableCell> NavigableCells;

        /// <summary>
        /// Returns the size of the object.
        /// </summary>
        /// <returns>the size of the object</returns>
        public Vec2i GetSize() => Size;

        /// <summary>
        /// Returns a list of a single <see cref="NavigableCell"/>.
        /// </summary>
        /// <returns>a list of a single <see cref="NavigableCell"/></returns>
        public IEnumerable<NavigableCell> GetNavigableCells() => NavigableCells;

        /// <summary>
        /// Decides if a <see cref="MapObject"/> can be placed.
        /// </summary>
        /// <param name="map">same as <see cref="Common.Simulation.Map"/></param>
        /// <param name="mapPosition">position of the object</param>
        /// <returns><c>true</c></returns>
        public virtual bool CanPlace(Map map, MapPosition mapPosition) => true;

        /// <summary>
        /// Places a <see cref="MapObject"/>.
        /// </summary>
        /// <param name="map">same as <see cref="Common.Simulation.Map"/></param>
        /// <param name="mapPosition">position of the object</param>
        /// <returns>the object placed</returns>
        public abstract MapObject Place(Map map, MapObjectPosition position);
    }
}
