using System;

using Model.Cartography;
using Model.Common;

namespace Model.Landscape.Blueprints
{
    /// <summary>
    /// Blueprint for a <see cref="Pavement"/>.
    /// </summary>
    [Serializable]
    public class PavementBlueprint : ObjectBlueprint
    {
        public int GarbageCanPrice;

        /// <summary>
        /// Creates a new <see cref="Pavement"/> and adds it to the <see cref="Park.pavements"/> list.
        /// </summary>
        /// <remarks>
        /// The entrance (created by <see cref="Park.Park"/>) is added to the list by the park.
        /// Doing it here would cause infinite recursion.
        /// </remarks>
        /// <param name="map">same as <see cref="Simulation.Map"/></param>
        /// <param name="position">the position of the pavement</param>
        /// <returns>the new <see cref="Pavement"/></returns>
        public override MapObject Place(Map map, MapObjectPosition position) {
            var obj = new Pavement(this, position);
            if (this != Simulation.Settings.EntranceBlueprint)
                Park.Instance.Pavements.Add(obj);
            return obj;
        }
    }
}
