using System;

using Model.Cartography;
using Model.Common;

namespace Model.Landscape.Blueprints
{
    /// <summary>
    /// Blueprint for a <see cref="VisitableBuilding"/>.
    /// </summary>
    [Serializable]
    public class VisitableBuildingBlueprint : BuildingBlueprint
    {
        public int Capacity;
        public int QueueCapacity;
        public int EntryFee;
        public int EffectOnMood;
        public int EffectOnSatiety;
        public int MaintenanceCostPerRide;
        public int MinVisitorCountToStart;
        public int TimePerRound;

        /// <summary>
        /// Creates a new <see cref="VisitableBuilding"/> and adds it to the <see cref="Park.visitableBuildings"/> list.
        /// </summary>
        /// <param name="map">same as <see cref="Simulation.Map"/></param>
        /// <param name="position">the position of the building</param>
        /// <returns>the new <see cref="VisitableBuilding"/></returns>
        public override MapObject Place(Map map, MapObjectPosition position) {
            var obj = new VisitableBuilding(this, position);
            Park.Instance.VisitableBuildings.Add(obj);
            return obj;
        }
    }
}
