using System;

using Model.Cartography;
using Model.Landscape.Blueprints;

namespace Model.Landscape
{
    /// <summary>
    /// Interface for unifying generic subtypes of staff building classes.
    /// </summary>
    public interface IStaffBuilding : IBuilding { }

    /// <summary>
    /// Base class for staff buidings, implements logic for spawning staff.
    /// </summary>
    /// <typeparam name="T"></typeparam>
    [Serializable]
    public abstract class StaffBuilding<T> : Building<T>, IStaffBuilding where T : StaffBuildingBlueprint
    {
        private int staffToSpawn;

        /// <summary>
        /// Constructor of staff building.
        /// </summary>
        /// <param name="blueprint"></param>
        /// <param name="position"></param>
        protected StaffBuilding(T blueprint, MapObjectPosition position) : base(blueprint, position) {
            staffToSpawn = blueprint.SpawnedStaffCount;
        }

        /// <summary>
        /// Spawns staff with the help of <see cref="SpawnStaff"/> if any is left.
        /// To be called on each tick.
        /// </summary>
        public override void Tick() {
            base.Tick();

            if (IsOperational && staffToSpawn > 0) {
                SpawnStaff();
                staffToSpawn--;
            }
        }

        /// <summary>
        /// Abstract function for spawning staff.
        /// </summary>
        protected abstract void SpawnStaff();
    }
}
