using System;
using System.Collections.Generic;
using System.Numerics;

using Model.Cartography.Nav;
using Model.Inspection;
using Model.Landscape;

namespace Model.People
{
    /// <summary>
    /// Class of cleaning staff.
    /// </summary>
    public class CleaningStaff : Staff
    {
        public override string Name => "Cleaner";

        public CleaningStaff(Vector2 position, VertexHandle entryHandle, float speed, string name = null)
            : base(position, entryHandle, speed, name) { }

        /// <summary>
        /// Gets the actions the player can perform on cleaning staff.
        /// </summary>
        /// <returns>A list of one <see cref="Command"/> for target selection.</returns>
        public override IEnumerable<Command> GetCommands() {
            List<Command> list = new List<Command>()
            {
                new Command("Send to pavement",
                    SelectTarget,
                    new Command.Signature() {
                        ReturnType = typeof(void),
                        Arguments = new List<Type>(){ typeof(Pavement) }
                    },
                    () => true)
            };
            return list;
        }

        private object SelectTarget(object[] arg) {
            if (arg.Length < 1)
                throw new ArgumentException("Missing required parameter for command (target destination)");

            Pavement target = arg[0] as Pavement;
            if (target == null)
                throw new ArgumentException("Invalid argument for command (target destination)");

            Destination = target;
            return null;
        }
    }
}
