using System.Numerics;

using Model.Cartography;
using Model.Cartography.Nav;
using Model.Common;
using Model.Inspection;

namespace Model.People
{
    /// <summary>
    /// Base class of staff, responsible for differentiating and handling idle state.
    /// </summary>
    public class Staff : Person
    {
        protected Property<bool> idle;
        public bool Idle { get => idle; }

        /// <summary>
        /// Destination of the staff. Successfully setting this will cause the staff to
        /// no longer be considered idle.
        /// </summary>
        public override MapObject Destination {
            get => base.Destination;
            set {
                base.Destination = value;
                if (Destination != null)
                    idle.Value = false;
            }
        }

        /// <summary>
        /// Constructor of staff. Sets idle property to true.
        /// </summary>
        /// <param name="position"></param>
        /// <param name="entryHandle"></param>
        /// <param name="speed"></param>
        /// <param name="name"></param>
        protected Staff(Vector2 position, VertexHandle entryHandle, float speed, string name = null) : base(position, entryHandle, speed, name) {
            idle = new Property<bool>("Idle", value: true);
        }

        /// <summary>
        /// Steps the staff if visible. Chooses a random pavement for destination if
        /// none is currently set. To be called on each tick.
        /// </summary>
        public override void Tick() {
            base.Tick();

            if (Destination == null) {
                Destination = Park.Instance.Pavements[Simulation.Random.Next(Park.Instance.Pavements.Count)];
                idle.Value = true;
            }
        }
    }
}
