using NUnit.Framework;

using Model.Cartography;

namespace Tests.Model.Cartography {
    public class Test_Vec2i
    {
        [Test]
        public void TestRotation()
        {
            Vec2i v = new Vec2i(1, 2);

            // ccw rotation
            v.Rotate90CCW();
            Assert.AreEqual(v, new Vec2i(-2, 1));

            v.Rotate90CCW();
            Assert.AreEqual(v, new Vec2i(-1, -2));

            v.Rotate90CCW();
            Assert.AreEqual(v, new Vec2i(2, -1));

            v.Rotate90CCW();
            Assert.AreEqual(v, new Vec2i(1, 2));

            // cw rotation
            v.Rotate90CW();
            Assert.AreEqual(v, new Vec2i(2, -1));

            v.Rotate90CW();
            Assert.AreEqual(v, new Vec2i(-1, -2));

            v.Rotate90CW();
            Assert.AreEqual(v, new Vec2i(-2, 1));

            v.Rotate90CW();
            Assert.AreEqual(v, new Vec2i(1, 2));

            // 180deg rotation
            v.Rotate180();
            Assert.AreEqual(v, new Vec2i(-1, -2));

            v.Rotate180();
            Assert.AreEqual(v, new Vec2i(1, 2));
        }

        [Test]
        public void TestSwap()
        {
            int [,] tests = {
                {1, 2},
                {-3, 4},
                {5, 2},
                {-1, -1},
                {2, 2},
                {3, 4},
            };

            for (int i = 0; i < tests.GetLength(0); i++) {
                var v = new Vec2i(tests[i, 0], tests[i, 1]);
                v.Swap();
                Assert.AreEqual(v, new Vec2i(tests[i, 1], tests[i, 0]));
            }
        }

        [Test]
        public void TestAdd()
        {
            Assert.AreEqual(new Vec2i(0, 0).Add(1, 2).Add(-3, 5).Add(3, -2), new Vec2i(1, 5));
            Assert.AreEqual(new Vec2i(-5, -4).Add(-1, 2).Add(2, -3).Add(4, 5), new Vec2i(0, 0));
            Assert.AreEqual(new Vec2i(1, 1).Add(-1, -1).Add(1, 1).Add(-1, -1), new Vec2i(0, 0));
            Assert.AreEqual(new Vec2i(1, 2).Add(1, -1).Add(-2, -3).Add(-1, 5), new Vec2i(-1, 3));
            Assert.AreEqual(new Vec2i(1, 1).Add(1, 1).Add(1, 1), new Vec2i(3, 3));
        }
    }
}
