using NUnit.Framework;
using System.Collections.Generic;
using System.Numerics;

using Model.Cartography;
using Model.Common;
using Model.Landscape.Blueprints;
using Model.People;

namespace Tests.Model.People
{
    class Test_Staff
    {
        private Simulation.Config config = new Simulation.Config
        {
            VisitorArrivalChance = 0,
            EntranceBlueprint = new PavementBlueprint
            {
                Size = new Vec2i { X = 1, Y = 1 },
                NavigableCells = new List<NavigableCell> {
                    new NavigableCell {
                        Position = new Vec2i { X = 0, Y = 0 },
                        OpenDirections = new List<Orientation> {
                            Orientation.NORTH,
                            Orientation.EAST,
                            Orientation.SOUTH,
                            Orientation.WEST,
                        },
                    },
                },
            },
            EntrancePosition = new Vector2(0, 0),
            GridSize = new Vec2i { X = 2, Y = 1 },
        };


        [SetUp]
        public void Init() {
            Simulation.CreateOnce(config);

            Simulation.Instance.Map.Build(
                new MaintenanceBuildingBlueprint
                {
                    Size = new Vec2i { X = 1, Y = 1 },
                    NavigableCells = new List<NavigableCell> {
                        new NavigableCell {
                            Position = new Vec2i { X = 0, Y = 0 },
                            OpenDirections = new List<Orientation> {
                                Orientation.WEST
                            },
                        },
                    },
                    SpawnedStaffCount = 1
                },
                new MapPosition
                {
                    Orientation = Orientation.NORTH,
                    Coords = new Vec2i { X = 1, Y = 0 },
                });

            Assert.AreEqual(1, Park.Instance.StaffBuildings.Count);

            Simulation.Instance.Tick();
        }

        [TearDown]
        public void TearDown() {
            Simulation.DestroyInstance();
        }

        [Test]
        public void TestStaffSpawning() {
            Assert.AreEqual(1, Simulation.Instance.People.Count);
            Assert.AreEqual(1, MaintenanceDispacher.Maintainers.Count);
            Assert.IsTrue(Simulation.Instance.People[0] is MaintenanceStaff);
            Assert.AreEqual(Simulation.Instance.People[0], MaintenanceDispacher.Maintainers[0]);
        }

        [Test]
        public void TestDestination() {
            Assert.AreEqual(1, Park.Instance.Pavements.Count);
            Assert.AreEqual(Park.Instance.Pavements[0], MaintenanceDispacher.Maintainers[0].Destination);
        }
    }
}
