using System;
using UnityEngine;

using Model.Common;

/// <summary>
/// Class responsible for displaying building specific things in the view.
/// </summary>
public class BuildingBehaviour : DisplayBehaviour
{
    /// <summary>
    /// The parent gameobject of decorations displayed while the building is broken or under construction.
    /// </summary>
    [Header("Building specific")]
    [SerializeField] private GameObject constructionDecorations;

    /// <summary>
    /// Initialize the DisplayBehaviour and register state change events.
    /// </summary>
    /// <param name="displayedObject"></param>
    public override void Init(IDisplayable displayedObject) {
        base.Init(displayedObject);

        var building = displayedObject as IDisplayableBuilding;
        if (building == null)
            throw new ArgumentException("BuildingBehaviour must be initialized with IDisplayableBuilding");

        building.IsUnderConstruction.Changed += (_, underConstruction) => {
            constructionDecorations.SetActive(underConstruction);
        };

        building.NeedsRepair.Changed += (_, needsRepair) => {
            constructionDecorations.SetActive(needsRepair);
        };

        constructionDecorations.SetActive(true);
    }
}
