using UnityEngine;

using Model.Common;
using Model.Landscape.Blueprints;

/// <summary>
/// Configuration class for general game parameters.
/// </summary>
[CreateAssetMenu(fileName = "GameConfig", menuName = "ScriptableObjects/GameConfig", order = 0)]
public class GameConfig : ScriptableObject
{
    [SerializeField]
    private Simulation.Config config;

    /// <summary>
    /// Settings for running the simulation.
    /// </summary>
    public Simulation.Config Config { get => config; }

    /// <summary>
    /// Reference to the scriptableobject containing the blueprint used for spawning the entrance.
    /// </summary>
    [SerializeField]
    private PavementData entranceData;

    /// <summary>
    /// Overwrites some values in the configuration from other config files.
    /// Currently used for keeping the entrance's blueprint in sync with the pavement's blueprint.
    /// </summary>
    public void InsertConfigs() {
        config.EntranceBlueprint = entranceData.Blueprint as PavementBlueprint;
    }
}
