using System.Collections;
using System.Collections.Generic;
using UnityEngine;

using Model.Cartography;

public static class Extensions
{
    /// <summary>
    /// Adds a $ to the end of the string.
    /// </summary>
    /// <param name="str"></param>
    /// <returns></returns>
    public static string WithCurrency(this string str) => str + " $";

    private static readonly int[] sin = { 0, 1, 0, -1 };
    private static readonly int[] cos = { 1, 0, -1, 0 };
    public static Vector2Int RotateRight(this Vector2Int v) => new Vector2Int(v.y, -v.x);
    public static Vector2Int Rotate90(this Vector2Int v, int rotations) {
        rotations %= 4;
        if (rotations < 0)
            rotations += 4;

        return new Vector2Int(v.x * cos[rotations] - v.y * sin[rotations], v.x * sin[rotations] + v.y * cos[rotations]);
    }

    /// <summary>
    /// Converts an integer to an orientation respecting the cyclic nature of rotations.
    /// </summary>
    /// <param name="a">The integer to convert to an orientation.</param>
    /// <returns></returns>
    public static Orientation ToOrientation(this int a) {
        a %= 4;
        if (a < 0)
            a += 4;
        return (Orientation)a;
    }

    /// <summary>
    /// Converts a Vector2 position on the x-z axis to world(unity) space respecting the GridScale set in the BuildingPlacer.
    /// </summary>
    /// <param name="v"></param>
    /// <returns></returns>
    public static Vector3 ToVector3Scaled(this System.Numerics.Vector2 v) {
        return new Vector3(v.X, 0, v.Y * BuildingPlacer.Instance.GridScale);
    }

    public static Vec2i ToVec2i(this Vector2Int v) => new Vec2i() { X = v.x, Y = v.y };
}
