using UnityEngine;
using UnityEngine.UI;
using TMPro;

/// <summary>
/// Static class for implementing a MessageBox that can be used similarly to the one in WinForms.
/// </summary>
static class MessageBox
{
    private const string prefabPath = "MessageBox"; // same as: */Resources/MessageBox.prefab

    private static int openCount = 0;
    private static readonly Vector3 offset = new Vector3(50, 50, 0);

    /// <summary>
    /// Display the passed string as a message in a new messagebox.
    /// </summary>
    /// <param name="message"></param>
    public static void Show(string message) {
        var prefab = Resources.Load(prefabPath);
        GameObject messageBox = Object.Instantiate(prefab) as GameObject;
        messageBox.transform.SetParent(GameObject.Find("UI").transform);
        RectTransform rt = messageBox.transform as RectTransform;

        // Offset position to prevent open MessageBoxes from overlapping exactly.
        rt.anchoredPosition = Vector3.zero + openCount * offset; 

        TMP_Text text = messageBox.transform.Find("Message").GetComponent<TMP_Text>();
        Button okButton = messageBox.transform.Find("OK").GetComponent<Button>();

        text.text = message;
        openCount++;

        okButton.onClick.AddListener(() => {
            Object.Destroy(messageBox); // Can't call Destroy directly in non MonoBehaviour classes
            openCount--;
        });
    }
}
