using System.Collections;
using System.Collections.Generic;
using UnityEngine;

/// <summary>
/// Helper class ensuring that some manager MonoBehaviours are only placed once into the scene.
/// </summary>
/// <typeparam name="T"></typeparam>
public class SingletonMonobehaviour<T> : MonoBehaviour where T: SingletonMonobehaviour<T>
{
    private static T instance;

    public static T Instance { get => instance; }

    /// <summary>
    /// Used for setting the static instance and to ensure that only one instance can exist at a time.
    /// Note: We can't use the constructor because of the way unity loads MonoBehaviours.
    /// </summary>
    public void Awake() {
        if (instance == null)
            instance = (T)this;
        else {
            Debug.LogError("Error: SingletonMonobehaviour instantiated multiple times!");
            Destroy(this);
        }
    }
}
