using UnityEngine;
using UnityEngine.UI;

/// <summary>
/// Helper class for scrolling a scrollview manually.
/// Used for the < and > buttons in the building selection menu.
/// </summary>
public class ScrollerHelper : MonoBehaviour
{
    [SerializeField] private Scrollbar scrollbar;
    [SerializeField] private float scrollAmount;
    [SerializeField] private RectTransform contentRect;

    private float target;
    public float LerpT = 0.1f;

    private void Awake() {
        scrollbar = GetComponent<Scrollbar>();
    }

    private void Update() {
        scrollbar.value = Mathf.Lerp(scrollbar.value, target, LerpT);
    }

    public void ScrollRight() {
        // scrollbar.value (hence target) must be in the range 0.0 to 1.0
        target += scrollAmount / contentRect.rect.width;
        target = Mathf.Clamp01(target);
    }

    public void ScrollLeft() {
        // scrollbar.value (hence target) must be in the range 0.0 to 1.0
        target -= scrollAmount / contentRect.rect.width;
        target = Mathf.Clamp01(target);
    }
}
