using UnityEngine;

/// <summary>
/// UI Helper class for toggling GameObjects.
/// </summary>
public class ToggleGroup : MonoBehaviour
{
    private GameObject lastActivated;

    /// <summary>
    /// If the target is active (is the last activated GameObject in the group) it will be deactivated.
    /// If another GameObject is the last activated GameObject, target will be activated and the old GameObject deactivated.
    /// Note: In order for this to work, all buttons used for toggling GameObjects in the group must use the same ToggleGroup instance to do so.
    /// </summary>
    /// <param name="obj">GameObject to toggle</param>
    public void Toggle(GameObject obj) {
        obj.SetActive(!obj.activeSelf);
        if (lastActivated == obj)
            return;

        lastActivated?.SetActive(false);
        lastActivated = obj;
    }

    public void Disable() {
        lastActivated?.SetActive(false);
        lastActivated = null;
    }
}
