using System.Collections;
using System.Collections.Generic;
using UnityEngine;

/// <summary>
/// UI helper for changing UI Modes when a button is clicked.
/// </summary>
public class UIModeChanger : MonoBehaviour
{
    [SerializeField] private UIMode targetMode;

    /// <summary>
    /// Changes UI Mode to the targetMode if the target GameObject is active,
    /// changes it back to normal otherwise.
    /// Used along with ToggleGroup for the building selection menu.
    /// </summary>
    /// <param name="target">The GameObject to check whether it's activated.</param>
    public void MatchActiveSelf(GameObject target) {
        if (target.activeSelf)
            UIManager.Instance.ChangeMode(targetMode);
        else
            UIManager.Instance.ChangeMode(UIMode.NORMAL);
    }

    /// <summary>
    /// Changes UI mode to the targetMode.
    /// </summary>
    public void Change() {
        UIManager.Instance.ChangeMode(targetMode);
    }
}
