#include <iostream>
#include <vector>
#include <queue>
#include <string>
#include <string_view>
#include <algorithm>
#include <cassert>
#include <cstdio>
#include <ctime>

struct uduw_graph {
	std::vector<std::vector<int>> adj_list;

	size_t size() const {
		return adj_list.size();
	}

	int add_vertex() {
		adj_list.emplace_back();
		return adj_list.size() - 1;
	}

	void add_edge(int a, int b) {
		assert(0 <= a);
		assert(0 <= b);

		adj_list.at(a).emplace_back(b);
		adj_list.at(b).emplace_back(a);
	}

	std::vector<int> get_shortest_path(int from, int to) const {
		assert(0 <= from);
		assert(0 <= to);
		assert(from < (int) adj_list.size());
		assert(to < (int) adj_list.size());

		std::vector<int> par(adj_list.size(), -1);
		std::queue<int> q;

		par[to] = to;
		q.push(to);

		while (!q.empty()) {
			int u = q.front(); q.pop();

			for (const auto &v : adj_list[u]) {
				if (par[v] != -1)
					continue;

				par[v] = u;

				if (v == from)
					goto out;

				q.push(v);
			}
		}

		if (par[from] == -1)
			return {};

	out:
		std::vector<int> path;

		from = par[from];

		while (to != from) {
			path.push_back(from);
			from = par[from];
		}

		path.push_back(from);

		return path;
	}
};

struct route {
	int at, to;

	bool operator == (const route &other) const {
		return at == other.at && to == other.to;
	}
};

int main(int argc, char *argv[]) {
	std::string line;
	
	int iters = 10000;
	unsigned seed = std::time(nullptr);

	if (argc > 1) {
		iters = std::stoi(argv[1]);
		assert(iters > 0);
	}

	if (argc > 2) {
		seed = std::stoi(argv[2]);
	}

	uduw_graph g;
	std::vector<route> routes;

	std::srand(seed);
	std::fprintf(stderr, "seed %u\n", seed);


	for (int i = 0; i < iters; i++) {
		int r = std::rand() % 4;

		if (r == 0) {
			int id = g.add_vertex();

			std::printf("add_vertex = %d\n", id);
		} else if (r == 1 && g.size() >= 2) {
			int x = std::rand() % g.size();
			int y = std::rand() % g.size();

			if (std::find(std::begin(g.adj_list[x]), std::end(g.adj_list[x]), y) == std::end(g.adj_list[x])) {
				g.add_edge(x, y);
				std::printf("add_edge %d %d = \n", x, y);
			}

		} else if (r == 2 && g.size() >= 2) {
			int x = std::rand() % g.size();
			int y = std::rand() % g.size();

			if (std::find(std::begin(routes), std::end(routes), route {x, y}) == std::end(routes) &&
				std::find(std::begin(routes), std::end(routes), route {y, x}) == std::end(routes)) {

				routes.push_back({x, y});
				std::printf("plan_route %d %d = \n", x, y);
			}

		} else if (r == 3 && routes.size() >= 1) {
			int id = rand() % routes.size();
			auto &r = routes[id];

			auto p = g.get_shortest_path(r.at, r.to);

			if (!p.empty()) {
				std::printf("get_next %d %d = %d\n", r.at, r.to, p[0]);

				r.at = p[0];

				if (r.at == r.to)
					routes.erase(std::begin(routes) + id);
			}
		}
	}
}
